ErrorHandler class

Constructors

ErrorHandler()
factory
ErrorHandler.internal()

Properties

errorResponse ↔ ErrorResponse
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleError(dynamic error) → ErrorResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited